==> zio-aws-comprehend_3-5.17.104.7-sources.jar: zio/aws/comprehend/model/ListTopicsDetectionJobsRequest.scala <==
package zio.aws.comprehend.model
import java.lang.Integer
import zio.aws.comprehend.model.primitives.MaxResultsInteger
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListTopicsDetectionJobsRequest(
    filter: Option[zio.aws.comprehend.model.TopicsDetectionJobFilter] = None,
    nextToken: Option[String] = None,
    maxResults: Option[MaxResultsInteger] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest = {
    import ListTopicsDetectionJobsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
      .builder()
      .optionallyWith(filter.map(value => value.buildAwsValue()))(_.filter)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value => MaxResultsInteger.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.ListTopicsDetectionJobsRequest.ReadOnly =
    zio.aws.comprehend.model.ListTopicsDetectionJobsRequest
      .wrap(buildAwsValue())
}
object ListTopicsDetectionJobsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.ListTopicsDetectionJobsRequest =
      zio.aws.comprehend.model.ListTopicsDetectionJobsRequest(
        filter.map(value => value.asEditable),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def filter
        : Option[zio.aws.comprehend.model.TopicsDetectionJobFilter.ReadOnly]
    def nextToken: Option[String]
    def maxResults: Option[MaxResultsInteger]
    def getFilter: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.TopicsDetectionJobFilter.ReadOnly
    ] = AwsError.unwrapOptionField("filter", filter)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResultsInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
  ) extends zio.aws.comprehend.model.ListTopicsDetectionJobsRequest.ReadOnly {
    override val filter
        : Option[zio.aws.comprehend.model.TopicsDetectionJobFilter.ReadOnly] =
      scala
        .Option(impl.filter())
        .map(value =>
          zio.aws.comprehend.model.TopicsDetectionJobFilter.wrap(value)
        )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val maxResults: Option[MaxResultsInteger] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.comprehend.model.primitives.MaxResultsInteger(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
  ): zio.aws.comprehend.model.ListTopicsDetectionJobsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-comprehend_3-5.20.17.1-sources.jar: zio/aws/comprehend/model/ListTopicsDetectionJobsRequest.scala <==
package zio.aws.comprehend.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.comprehend.model.primitives.MaxResultsInteger
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListTopicsDetectionJobsRequest(
    filter: Optional[zio.aws.comprehend.model.TopicsDetectionJobFilter] =
      Optional.Absent,
    nextToken: Optional[String] = Optional.Absent,
    maxResults: Optional[MaxResultsInteger] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest = {
    import ListTopicsDetectionJobsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
      .builder()
      .optionallyWith(filter.map(value => value.buildAwsValue()))(_.filter)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value => MaxResultsInteger.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.ListTopicsDetectionJobsRequest.ReadOnly =
    zio.aws.comprehend.model.ListTopicsDetectionJobsRequest
      .wrap(buildAwsValue())
}
object ListTopicsDetectionJobsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.ListTopicsDetectionJobsRequest =
      zio.aws.comprehend.model.ListTopicsDetectionJobsRequest(
        filter.map(value => value.asEditable),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def filter
        : Optional[zio.aws.comprehend.model.TopicsDetectionJobFilter.ReadOnly]
    def nextToken: Optional[String]
    def maxResults: Optional[MaxResultsInteger]
    def getFilter: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.TopicsDetectionJobFilter.ReadOnly
    ] = AwsError.unwrapOptionField("filter", filter)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResultsInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
  ) extends zio.aws.comprehend.model.ListTopicsDetectionJobsRequest.ReadOnly {
    override val filter
        : Optional[zio.aws.comprehend.model.TopicsDetectionJobFilter.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filter())
        .map(value =>
          zio.aws.comprehend.model.TopicsDetectionJobFilter.wrap(value)
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val maxResults: Optional[MaxResultsInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.comprehend.model.primitives.MaxResultsInteger(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest
  ): zio.aws.comprehend.model.ListTopicsDetectionJobsRequest.ReadOnly =
    new Wrapper(impl)
}
